@@ -1,5 +1,6 @@
 class MemoriousException(Exception):
     """Base exception class."""
+
     pass
 
 
@@ -13,6 +14,7 @@ class ConfigurationError(MemoriousException):
 
 class RuleParsingException(MemoriousException):
     """A rule encounters something it can't parse."""
+
     pass
 
 
@@ -22,15 +24,17 @@ class StorageFileMissing(MemoriousException):
     def __init__(self, content_hash, file_name=None):
         self.content_hash = content_hash
         self.file_name = file_name
-        msg = 'Could not load: %s' % content_hash
+        msg = "Could not load: %s" % content_hash
         super(StorageFileMissing, self).__init__(msg)
 
 
 class ParseError(MemoriousException):
     """An error while parsing a structured HTTP response."""
+
     pass
 
 
 class RateLimitException(Exception):
     """Rate limit exceeded for a crawler operation"""
+
     pass
