@@ -2,14 +2,16 @@ import os
 import io
 import yaml
 import logging
-from datetime import timedelta, datetime
+import re
+from datetime import timedelta
 from importlib import import_module
 from servicelayer.cache import make_key
 from servicelayer.jobs import Dataset, Job
+from servicelayer.extensions import get_entry_point
 
 from memorious import settings
 from memorious.core import conn, tags
-from memorious.model import Event, Crawl, Queue
+from memorious.model import Crawl, Queue
 from memorious.logic.stage import CrawlerStage
 
 log = logging.getLogger(__name__)
@@ -17,57 +19,44 @@ log = logging.getLogger(__name__)
 
 class Crawler(object):
     """A processing graph that constitutes a crawler."""
+
     SCHEDULES = {
-        'disabled': None,
-        'hourly': timedelta(hours=1),
-        'daily': timedelta(days=1),
-        'weekly': timedelta(weeks=1),
-        'monthly': timedelta(weeks=4)
+        "disabled": None,
+        "hourly": timedelta(hours=1),
+        "daily": timedelta(days=1),
+        "weekly": timedelta(weeks=1),
+        "monthly": timedelta(weeks=4),
     }
 
     def __init__(self, manager, source_file):
         self.manager = manager
         self.source_file = source_file
-        with io.open(source_file, encoding='utf-8') as fh:
+        with io.open(source_file, encoding="utf-8") as fh:
             self.config_yaml = fh.read()
             self.config = yaml.safe_load(self.config_yaml)
 
         self.name = os.path.basename(source_file)
-        self.name = self.config.get('name', self.name)
-        self.description = self.config.get('description', self.name)
-        self.category = self.config.get('category', 'scrape')
-        self._schedule = self.config.get('schedule', 'disabled')
-        self.init_stage = self.config.get('init', 'init')
-        self.delta = Crawler.SCHEDULES.get(self.schedule)
-        self.delay = int(self.config.get('delay', 0))
-        self.expire = int(self.config.get('expire', settings.EXPIRE)) * 84600
-        self.stealthy = self.config.get('stealthy', False)
+        self.name = self.config.get("name", self.name)
+        self.validate_name()
+        self.description = self.config.get("description", self.name)
+        self.category = self.config.get("category", "scrape")
+        self.init_stage = self.config.get("init", "init")
+        self.delay = int(self.config.get("delay", 0))
+        self.expire = int(self.config.get("expire", settings.EXPIRE)) * 84600
+        self.stealthy = self.config.get("stealthy", False)
         self.queue = Dataset(conn, self.name)
-        self.aggregator_config = self.config.get('aggregator', {})
+        self.aggregator_config = self.config.get("aggregator", {})
 
         self.stages = {}
-        for name, stage in self.config.get('pipeline', {}).items():
+        for name, stage in self.config.get("pipeline", {}).items():
             self.stages[name] = CrawlerStage(self, name, stage)
 
-    def check_due(self):
-        """Check if the last execution of this crawler is older than
-        the scheduled interval."""
-        if self.is_running:
-            return False
-        if self.delta is None:
-            return False
-        last_run = self.last_run
-        if last_run is None:
-            return True
-        now = datetime.utcnow()
-        if now > last_run + self.delta:
-            return True
-        return False
-
-    @property
-    def schedule(self):
-        schedule = Crawl.get_schedule(self) or self._schedule
-        return schedule if schedule in self.SCHEDULES else 'disabled'
+    def validate_name(self):
+        if not re.match(r"^[A-Za-z0-9_-]+$", self.name):
+            raise ValueError(
+                "Invalid crawler name: %s. "
+                "Allowed characters: A-Za-z0-9_-" % self.name
+            )
 
     @property
     def aggregator_method(self):
@@ -75,10 +64,16 @@ class Crawler(object):
             method = self.aggregator_config.get("method")
             if not method:
                 return
-            if ':' in method:
-                package, method = method.rsplit(':', 1)
+            # method A: via a named Python entry point
+            func = get_entry_point("memorious.operations", method)
+            if func is not None:
+                return func
+            # method B: direct import from a module
+            if ":" in method:
+                package, method = method.rsplit(":", 1)
                 module = import_module(package)
                 return getattr(module, method)
+            raise ValueError("Unknown method: %s", self.method_name)
 
     def aggregate(self, context):
         if self.aggregator_method:
@@ -89,46 +84,31 @@ class Crawler(object):
     def flush(self):
         """Delete all run-time data generated by this crawler."""
         self.queue.cancel()
-        Event.delete(self)
         Crawl.flush(self)
         self.flush_tags()
 
     def flush_tags(self):
-        tags.delete(prefix=make_key(self, 'tag'))
-
-    def flush_events(self):
-        Event.delete(self)
+        tags.delete(prefix=make_key(self, "tag"))
 
     def cancel(self):
         Crawl.abort_all(self)
         self.queue.cancel()
 
-    @property
-    def should_timeout(self):
-        if self.last_run is None:
-            return False
-        now = datetime.utcnow()
-        return self.last_run < now - timedelta(seconds=settings.CRAWLER_TIMEOUT)  # noqa
-
-    def timeout(self):
-        log.warning("Crawler timed out: %s. Aggregator won't be run", self.name)  # noqa
-        self.cancel()
-
     def run(self, incremental=None, run_id=None):
         """Queue the execution of a particular crawler."""
         state = {
-            'crawler': self.name,
-            'run_id': run_id or Job.random_id(),
-            'incremental': settings.INCREMENTAL
+            "crawler": self.name,
+            "run_id": run_id or Job.random_id(),
+            "incremental": settings.INCREMENTAL,
+            "continue_on_error": settings.CONTINUE_ON_ERROR,
         }
         if incremental is not None:
-            state['incremental'] = incremental
+            state["incremental"] = incremental
 
         # Cancel previous runs:
         self.cancel()
-        # Flush out previous events data but keep the counts:
-        Event.delete_data(self)
-        Queue.queue(self.init_stage, state, {})
+        init_stage = self.get(self.init_stage)
+        Queue.queue(init_stage, state, {})
 
     @property
     def is_running(self):
@@ -158,7 +138,7 @@ class Crawler(object):
     @property
     def pending(self):
         status = self.queue.get_status()
-        return status.get('pending')
+        return status.get("pending")
 
     def get(self, name):
         return self.stages.get(name)
@@ -170,4 +150,4 @@ class Crawler(object):
         return iter(self.stages.values())
 
     def __repr__(self):
-        return '<Crawler(%s)>' % self.name
+        return "<Crawler(%s)>" % self.name
