@@ -2,6 +2,7 @@ import datetime
 from banal import ensure_list
 
 from memorious.core import datastore, get_rate_limit
+from memorious.model import Queue
 from memorious import settings
 
 
@@ -17,7 +18,7 @@ def _upsert(context, params, data):
             return
     data["__first_seen"] = data["__last_seen"]
     rate_limit = get_rate_limit("db", limit=settings.DB_RATE_LIMIT)
-    rate_limit.comply()
+    context.enforce_rate_limit(rate_limit)
     table.insert(data)
 
 
@@ -30,8 +31,10 @@ def _recursive_upsert(context, params, data):
         child_data_list = ensure_list(data.pop(key))
         if isinstance(child_data_list, dict):
             child_data_list = [child_data_list]
-        if not (isinstance(child_data_list, list) and
-                all(isinstance(i, dict) for i in child_data_list)):
+        if not (
+            isinstance(child_data_list, list)
+            and all(isinstance(i, dict) for i in child_data_list)
+        ):
             context.log.warn(
                 "Expecting a dict or a lost of dicts as children for key", key
             )
