@@ -1,7 +1,9 @@
+import pytest  # noqa
 from memorious.operations.documentcloud import documentcloud_query
 
 
 class TestDocumentCloud(object):
+    # @pytest.mark.skip(reason="documentcloud returning errors under load")
     def test_query(self, context, mocker):
         data = {}
         context.params["query"] = "money"
@@ -12,4 +14,4 @@ class TestDocumentCloud(object):
         documentcloud_query(context, data)
         assert context.emit.call_count >= 10
         assert context.recurse.call_count == 1
-        context.recurse.assert_called_once_with(data={'page': 2})
+        context.recurse.assert_called_once_with(data={"page": 2})
